# Gro API Client example: Prevented Plant

1. Follow the [instructions to install the Gro API Client](../../../../README.md). NOTE: requires a minimum client version of v1.40.3.
2. Download the [requirements file in this directory](./requirements.txt)
3. Run `pip install -r requirements.txt` (for MacOS and Linux) or `conda install --file windows-requirements.txt` (for Windows) to automatically install the required dependencies (see comment in the notebook regarding xgboost)
4. Download the notebook to your working directory
5. Run `jupyter notebook` to start the jupyter server and open the notebook in your web browser
